@@ -1,11 +1,11 @@
 package SPOPS::Export::DBI::Data;
 
-# $Id: Data.pm,v 3.1 2002/09/03 11:43:22 lachoy Exp $
+# $Id: Data.pm,v 3.2 2003/01/02 06:00:23 lachoy Exp $
 
 use strict;
 use base qw( SPOPS::Export::Object );
 
-$SPOPS::Export::DBI::Data::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Export::DBI::Data::VERSION  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
 
 sub create_header {
     my ( $self, $fields ) = @_;
@@ -64,4 +64,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
